const path = require('path');
const HappyPack = require('happypack');
const os = require('os');
const api = require('fie-api');
const glob = require('glob');

const toolkitConfig = api.config.get('toolkitConfig');
const happyThreadPool = HappyPack.ThreadPool({ size: os.cpus().length + 2 });
const cwd = process.cwd();

const srcPath = path.join(cwd, './src/');

const babelConfig = {
  presets: [
    require.resolve('@babel/preset-env'),
    require.resolve('@babel/preset-react')
  ]
};
const babelInclude = [path.join(cwd, 'src')];

function getEntries() {
  let entry = {};
  if (!toolkitConfig.entry) {
    glob
      .sync('*', {
        cwd: path.join(srcPath, 'pages')
      })
      .forEach(page => {
        entry[page] = ['./pages/' + page + '/index'];
      });
  } else {
    entry = toolkitConfig.entry;
  }
  return entry;
}
module.exports = {
  context: srcPath,
  target: 'web',
  entry: getEntries(),
  devServer: {
    disableHostCheck: true
  },
  output: {
    path: path.resolve(cwd, 'build'),
    filename: '[name].js'
  },
  module: {
    rules: [
      {
        test: /\.js|\.jsx?$/,
        include: babelInclude,
        use: [require.resolve('happypack/loader') + '?id=js'] // 'babel-loader' is also a legal name to reference
      },
      {
        test: /\.xml$/i,
        use: [require.resolve('happypack/loader') + '?id=xml']
      },
      {
        test: /\.less$/,
        use: [require.resolve('happypack/loader') + '?id=less']
      },
      {
        test: /\.json/,
        use: [require.resolve('happypack/loader') + '?id=json'],
        type: 'javascript/auto'
      }
    ]
  },
  resolve: {
    mainFields: ['main', 'module'],
    modules: [
      path.join(cwd, 'src'),
      path.join(cwd, 'node_modules'),
      'node_modules'
    ],
    extensions: ['.js', '.json', '.jsx', '.ts', '.tsx']
  },
  externals: {
    react: 'React',
    'react-dom': 'ReactDOM',
    ...toolkitConfig.externals
  },

  plugins: [
    new HappyPack({
      // cache: true,
      debug: true,
      id: 'js',
      loaders: [
        require.resolve('babel-loader') + '?' + JSON.stringify(babelConfig)
      ],
      threadPool: happyThreadPool
    }),
    new HappyPack({
      // cache: true,
      debug: true,
      id: 'less',
      loaders: [require.resolve('less-loader')],
      threadPool: happyThreadPool
    }),
    new HappyPack({
      debug: true,
      id: 'json',
      loaders: [require.resolve('json-loader')],
      threadPool: happyThreadPool
    }),
    new HappyPack({
      debug: true,
      id: 'xml',
      loaders: [require.resolve('dinamicx-xml-loader')]
    })
  ]
};
