/**
 * 打开服务器
 */

'use strict';

const fs = require('fs');
const path = require('path');
const spawn = require('cross-spawn');
const open = require('open');
const api = require('fie-api');
const webpack = require('webpack');
const openBrowser = require('react-dev-utils/openBrowser');

const WebpackDevServer = require('webpack-dev-server');
const webpackConfig = require('./config/webpack/dev.config');

const fieConfig = api.config;
const log = api.log('fie-toolkit-cz5');

module.exports = function* () {
  const toolkitConfig = fieConfig.get('toolkitConfig');
  process.env.DEV = 1;
  const port = toolkitConfig.port || '3333';
  const compiler = webpack(webpackConfig);
  let opened = false;
  compiler.hooks.afterEmit.tap('AfterEmitPlugin', () => {
    if (!opened) {
      openBrowser(`http://0.0.0.0:${port}/demo/index.html`);
      opened = true;
    }
  });
  const server = new WebpackDevServer(compiler, {
    publicPath: webpackConfig.output.publicPath,
    disableHostCheck: true,
    quiet: false,
    noInfo: true,
    overlay: true,
    stats: {
      colors: true
    }
  });
  server.listen(port, '0.0.0.0', function (err) {
    if (err) {
      console.error(err.message || err);
      process.exit(1);
    }
  });
};
